From 59398bc28021304f3f35b4f548c3fb3dddd54037 Mon Sep 17 00:00:00 2001
From: elvill <elias.villiger@uzh.ch>
Date: Sat, 8 Sep 2018 17:29:02 +0200
Subject: [PATCH] F6300 - Change disabled link to span; Adjust config baseUrl
 description

---
 extension/ext_conf_template.txt          | 2 +-
 extension/qfq/qfq/BuildFormBootstrap.php | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/extension/ext_conf_template.txt b/extension/ext_conf_template.txt
index 19988dc4b..eb95c430b 100644
--- a/extension/ext_conf_template.txt
+++ b/extension/ext_conf_template.txt
@@ -16,7 +16,7 @@ cmdConvert = convert
 # cat=config/config; type=string; label=Command 'wkhtmltopdf':Default is '/opt/wkhtmltox/bin/wkhtmltopdf'. Command to convert a HTML page to a PDF.
 cmdWkhtmltopdf = /opt/wkhtmltox/bin/wkhtmltopdf
 
-# cat=config/config; type=string; label=Base URL of the current Typo3 installation:Default is empty. Example: https://your.base.url/including/sub/dir. Will be used to convert local pages to PDF. For accessing protected pages, the current FE User session will be faked - therefore the exact URL is needed that cookies become valid.
+# cat=config/config; type=string; label=Base URL of the current Typo3 installation:Default is empty. Example: https://localhost/including/sub/dir. Will be used to convert local pages to PDF. For accessing protected pages, the current FE User session will be faked - therefore the exact URL is needed that cookies become valid.
 baseUrl =
 
 # cat=config/email; type=string; label=Options for SendEMail:Default is empty. General options. Check: http://caspian.dotconf.net/menu/Software/SendEmail. E.g.: 'sendEMail=-o tls=yes'
diff --git a/extension/qfq/qfq/BuildFormBootstrap.php b/extension/qfq/qfq/BuildFormBootstrap.php
index c76622fc3..2ffcd482d 100644
--- a/extension/qfq/qfq/BuildFormBootstrap.php
+++ b/extension/qfq/qfq/BuildFormBootstrap.php
@@ -383,8 +383,8 @@ class BuildFormBootstrap extends AbstractBuildForm {
         $attribute .= Support::doAttribute('class', "$class $disabled");
         $attribute .= Support::doAttribute('title', $toolTip);
 
-        // disabled links do not show tooltips
-        $wrapTag = $disabled == 'disabled' ? 'button' : 'a';
+        // disabled links do not show tooltips -> use a span
+        $wrapTag = $disabled == 'disabled' ? 'span' : 'a';
 
         return Support::wrapTag("<$wrapTag $attribute>", $element);
     }
-- 
GitLab